"""
  Dave Skura,2023
"""
import sys
from schemawizard_package.schemawizard import schemawiz

def main():
	if len(sys.argv) == 1 or sys.argv[1] == 'postgres_import.py': # no parameters
		print('usage: ')
		print('postgres_import.py [csv_filename] [tablename] [WithTruncate]') 
		print('')
		print('bool WithTruncate = [True,False]')

	elif (len(sys.argv) == 2) : 
		csv_filename = sys.argv[1]
		myexp = dbimport(csv_filename)

	elif (len(sys.argv) == 3) : 
		csv_filename = sys.argv[1]
		tablename = sys.argv[2]

		myexp = dbimport(csv_filename,tablename)

	elif (len(sys.argv) == 4) : 
		csv_filename = sys.argv[1]
		tablename = sys.argv[2]
		WithTruncate = bool(sys.argv[2])

		myexp = dbimport(csv_filename,tablename,WithTruncate)

	else:
		print('Error: Incorrect number of parameters.')
		print('')
		print('usage: ')
		print('postgres_import.py [csv_filename] [tablename] [WithTruncate]') 
		print('')
		print('bool WithTruncate = [True,False]')


class dbimport():
	def __init__(self,csv_filename,tablename='',WithTruncate=False):

		tbl = tablename
		dber = schemawiz()
		if ((tablename != '') and (dber.dbthings.postgres_db.does_table_exist(tablename))):
			dber.justload_postgres_from_csv(csv_filename,tablename,WithTruncate)
		else:
			output_ddl_filename = self.getoutputfilename(csv_filename,'z.' + tablename) + '.ddl'
			tbl = dber.createload_postgres_from_csv(csv_filename,tablename,output_ddl_filename)

		print(dber.dbthings.postgres_db.queryone('SELECT COUNT(*) FROM ' + tbl))

		print(csv_filename + ' imported to ' + tbl)

	def getoutputfilename(self,csv_filename,ddl_output_filename):
		# zetl_scripts/someetl/thisfile.csv
		filedelimiter = '\\'
		if csv_filename.find('/') > -1:
			filedelimiter = '/'

		newfile = ''
		partlist = csv_filename.split(filedelimiter)
		if partlist[0] != csv_filename:
			for i in range(0,len(partlist)-1):
				newfile += partlist[i] + filedelimiter

		newfile += ddl_output_filename

		return newfile

if __name__ == '__main__':
	#myexp = dbimport('sample.csv','canweather.sample6',True)
	#print(getoutputfilename('zetl_scripts/someetl/thisfile.csv','z.canweather.canadianpostalcodes.dll'))

	main()

		


"""
  Dave Skura, 2023
"""
import sys

from mysqldave_package.mysqldave import mysql_db #install pip install mysqldave_package

def main():
	if len(sys.argv) == 1 or sys.argv[1] == 'mysql_export.py': # no parameters
		print('usage: ')
		print('mysql_export.py [tablename] [csvfilename] [delimiter] ') 
		print('')

	elif (len(sys.argv) == 2) : 
		tablename = sys.argv[1]
		myexp = dbexport(tablename)
		print('Just Table')

	elif (len(sys.argv) == 3) : 
		tablename = sys.argv[1]
		csv_filename = sys.argv[2]
		myexp = dbexport(tablename,csv_filename)
		print('Just Table/file')

	elif (len(sys.argv) == 4) : 
		tablename = sys.argv[1]
		csv_filename = sys.argv[2]
		delimiter = sys.argv[3]
		myexp = dbexport(tablename,csv_filename,delimiter)
		print('Table/file/delimiter')

	else:
		print('Error: Incorrect number of parameters.')
		print('')
		print('usage: ')
		print('mysql_export.py [tablename] [csvfilename] [delimiter] ') 
		print('')

class dbexport():
	def __init__(self,tablename='',csv_filename='',delimiter='\t'):
		self.mydb = mysql_db()
		if csv_filename == '':
			csv_filename=tablename + '.tsv'

		self.mydb.export_table_to_csv(csv_filename,tablename,delimiter)
		self.mydb.close()

		print(tablename + ' exported to ' + csv_filename)


if __name__ == '__main__':
	
	main()

		




"""
  Dave Skura
  
"""
import os, sys
import msvcrt
import readchar
from run import zetl


def main():
	em = etl_menu()
	while True:
		print('')
		option_count = em.show_menu()
		print('')
		if option_count > 1:
			if option_count < 10:
				print('SINGLE CHAR ENTRY.  Select from 0 to ' + str(option_count-1))
				user_selection = int(readchar.readchar())
			else:
				user_msg = 'Select from 0 to ' + str(option_count-1)
				user_selection = input(user_msg) or option_count
				print("word entered: ", user_selection)

			if user_selection == 0:
				sys.exit(0)
			elif user_selection <= option_count and user_selection > -1:
				print("Running ", user_selection, em.etl_list[user_selection])
				em.run_zetl(em.etl_list[user_selection])
			else:
				print("You broke something ")

class etl_menu:
	def __init__(self):
		self.etl_path = os.getcwd() + '\\zetl_scripts'
		self.etl_list = []
		self.etlcount = 0
		self.findetls()

	def run_zetl(self,etl_name_to_run):
		run_parameter = ''
		my_zetl = zetl()
		my_zetl.zetldb.empty_zetl()						
		my_zetl.zetldb.load_folders_to_zetl() 
		my_zetl.proper_run(etl_name_to_run,run_parameter)

	def findetls(self):
		self.etl_list.append('exit from zetl.menu')
		subfolders = [ f.path for f in os.scandir(self.etl_path) if f.is_dir() ]
		for etlwithpath in subfolders:
			etl = etlwithpath.split(self.etl_path+'\\')[1]
			self.etl_list.append(etl)
		self.etlcount = len(self.etl_list)

	def show_menu(self):

		print ("zetl menu v1.0 \n --------------") #
		for nbr in range(0,self.etlcount):
			print(nbr,'\t' + self.etl_list[nbr])

		return self.etlcount

if __name__ == '__main__':
	main()
